comment this program contains transformations for the Hartford demographic study of 2000.

********************************************************************************************************************************************************************.
comment ID changes Page 1.
********************************************************************************************************************************************************************.
compute source = 2.
if range(id,1,216) source =1.
if range(id,451,454) source = 1.
variables labels source 'Sampling Frame from Which Survey is Derived'.
value labels source 1 'RDD'      2 'DJN'.
frequencies source.

********************************************************************************************************************************************************************.
comment residential changes Page 2.
********************************************************************************************************************************************************************.
compute clor=lor.
compute clorca=lorca.
recode clorca clor (0 thru 4=1) (5 thru 9=2) (10 thru 19=3) (20 thru 98=4).
var labels clorca 'length of residence at current address'.
var labels clor 'length of residence in local area'.
value labels clorca clor 1 '0-4 yrs' 2 '5-9 yrs' 3 '10-19   yrs' 4 '20+ yrs'.
frequencies clorca clor.

compute cclor = clor.
recode cclor (2 thru 4 = 2).
var labels cclor 'length of residence in largest categories'.
value labels cclor 1 'under 5 years' 2 '5 or more years'.
frequencies cclor clor.

*****************************************************************************************************************************************.
comment statements below were used to check that respondents who gave us a change of neighborhood really changed neighborhoods
	and that people who gave us a place moving to, actually were changing neighborhoods.
****************************************************************************************************************************************.
temporary.
select if movin eq 1.
summarize
  /tables=id zip oldnay 
  /format=validlist nocasenum total limit=1000
  /title='case summaries'
  /missing=variable
  /cells=count .

frequencies movin.
if (lor eq lorca) movin eq 3.
add value labels movin 3 'always lived at this address'.
frequencies movin.

Frequencies zip.

compute area = 4.
if (zip eq 6) area = 1.
if (zip eq 8) area = 2.
if (zip eq 7) area = 3.
variable labels area   'Geographic Areas'.
value labels area 1 'Westport'  2 'Weston'  3 'Wilton' 4 'Norwalk'.
frequencies area.

CROSSTABS
  /TABLES=zip  BY oldnay
  /FORMAT= AVALUE TABLES
  /CELLS= COUNT .

compute cmonths=months.
recode  cmonths (3 thru 7=1)(8 thru 12=2).
var labels cmonths 'months in residence'.
value labels cmonths 1 '3-7     months' 2 '8-12    months'.
frequencies cmonths.

compute defmove = 2.
if (move eq 1 and range(wmove,2,4)) defmove = 1.
var labels defmove 'definitely moving out of area'.
value labels defmove 1 'yes' 2 'no'.
frequencies defmove.

compute probmove = 2.
if (move eq 2 and range(wmove,2,4)) probmove = 1.
var labels probmove 'probably moving out of area'.
value labels probmove 1 'yes' 2 'no'.
frequencies probmove.

if any(move,3,4,9)  wmove = 10.
frequencies cmonths defmove probmove wmove.

comment calculates jews from former soviet union.
compute fsu = 1.
if (any(born1,65,71,72,76) and age1 lt 60) fsu = 3.
if (any(born2,65,71,72,76) and age2 lt 60) fsu = 4.
if (any(born3,65,71,72,76) and age3 lt 60) fsu = 5.
if (any(born4,65,71,72,76) and age4 lt 60) fsu = 6.
if any(lbefore,65,71,72,76) fsu = 2.
variable labels fsu 'household from the fsu'.
value labels fsu 1 'no' 2 'last previous residence in fsu' 3 'respondent born fsu' 4 'adult 2 born fsu' 5 'adult 3 born fsu' 6 'adult 4 born fsu'.
frequencies fsu.

********************************************************************************************************************************************************************.
comment Page 3: age groups in census age categories.
********************************************************************************************************************************************************************.
compute cage1=age1.
compute cage2=age2.
compute cage3=age3.
compute cage4=age4.
compute cagec1=agec1.
compute cagec2=agec2.
compute cagec3=agec3.
compute cagec4=agec4.
var labels  cage1 'age-respondent' cage2 'age-adult 2' cage3 'age-adult 3' cage4 'age-adult 4' cagec1 'age-child 1' cagec2 'age-child 2'
            cagec3 'age-child 3' cagec4 'age-child 4'.

recode cage1 to cagec4 (0 thru 4=1) (5 thru 9=2) (10 thru 14=3) (15 thru 19=4) (20 thru 24=5) (25 thru 29=6)  (30 thru 34=7) (35 thru 39=8) 
	(40 thru 44=9) (45 thru 49=10) (50 thru 54=11) (55 thru 59=12) (60 thru 64=13) (65 thru 69=14) (70 thru 74=15)
	(75 thru 79=16) (80 thru 84=17) (85 thru 89=18) (90 thru 99=19).

value labels  cage1 to cagec4 1 '0-4'  2 '5-9' 3 '10-14' 4 '15-19' 5 '20-24' 6 '25-29' 7 '30-34' 8 '35-39' 9 '40-44' 10 '45-49' 11 '50-54' 
	12 '55-59' 13 '60-64' 14 '65-69' 15 '70-74' 16 '75-79' 17 '80-84' 18 '85-89' 19 '90+'.

********************************************************************************************************************************************************************.
comment Page 3: age groups in school age categories.
********************************************************************************************************************************************************************.
compute      sage1=age1.
compute      sage2=age2.
compute      sage3=age3.
compute      sage4=age4.
compute      sagec1=agec1.
compute      sagec2=agec2.
compute      sagec3=agec3.
compute      sagec4=agec4.

var labels   sage1 'age-respondent' sage2 'age-adult 2' sage3 'age-adult 3' sage4 'age-adult 4' sagec1 'age-child 1' sagec2 'age-child 2'
             sagec3 'age-child 3' sagec4 'age-child4'.

recode sage1 to sagec4 (0 thru 5=1)(6 thru 12=2)(13 thru 17=3) (18 thru 24=4)(25 thru 34=5) 
	(35 thru 44=6) (45 thru 54=7) (55 thru 64=8)(65 thru 74=9)(75 thru 84=10) (85 thru 99=11).

value labels  sage1 to sagec3 1 '0-5' 2 '6-12'  3 '13-17' 4 '18-24 ' 5 '25-34 ' 6 '35-44' 7 '45-54'  8 '55-64 ' 9 '65-74 ' 10 '75-84 ' 11 '85+'.

********************************************************************************************************************************************************************.
comment Page 3: age groups in large age categories.
********************************************************************************************************************************************************************.
compute ccage1=cage1.
compute ccage2=cage2.
compute ccage3=cage3.
compute ccage4=cage4.
compute ccagec1=sagec1.
compute ccagec2=sagec2.
compute ccagec3=sagec3.
compute ccagec4=sagec4.
recode  ccage1 ccage2 ccage3 ccage4 (4 thru 7=2) (8 thru 10=3) (11 thru 13=4)(14,15=5) (16 thru 19 =6).
recode  ccagec1 ccagec2 ccagec3 ccagec4 (1 thru 3=1).

var labels  ccage1 'age of respondent' ccage2 'age of adult 2' ccage3 'age of adult 3' ccage4 'age of adult 4' ccagec1 'age of child 1'
            ccagec2 'age of child 2' ccagec3 'age of child 3' ccagec4 'age of child 4'.

value labels ccage1 ccage2 ccage3 ccage4 ccagec1 ccagec2 ccagec3 ccagec4  1 '0-17'       2 ' 18-34'     3 '35-49'      4 '50-64'     5 '65-74'    6 '75+'.
frequencies ccage1 ccage2 ccage3 ccage4 ccagec1 ccagec2 ccagec3 ccagec4 .

********************************************************************************************************************************************************************.
comment Page 3: age groups in categories for row percentage by area.
********************************************************************************************************************************************************************.
compute nage1=age1.
compute nage2=age2.
compute nage3=age3.
compute nage4=age4.
compute nagec1=agec1.
compute nagec2=agec2.
compute nagec3=agec3.
compute nagec4=agec4.
var labels  nage1 'age-respondent-rows' nage2 'age-adult 2-rows' nage3 'age-adult 3-rows' nage4 'age-adult 4-rows'
            nagec1 'age-child 1-rows' nagec2 'age-child 2-rows' nagec3 'age-child 3-rows' nagec4 'age-child 4-rows'.

recode nage1 to nagec4 (0 thru 5=1) (6 thru 12=2) (13 thru 17=3) (18 thru 24=4) (25 thru 34=5) (35 thru 49=6) (50 thru 64=7) (65 thru 74=8) (75 thru 99=9).

value labels  nage1 to nagec4 1 '0-5'  2 '6-12' 3 '13-17' 4 '18-24' 5 '25-34' 6 '35-49' 7 '50-64' 8 '65-74' 9 '75+'.

compute mage1=age1.
compute mage2=age2.
compute mage3=age3.
compute mage4=age4.
compute magec1=agec1.
compute magec2=agec2.
compute magec3=agec3.
compute magec4=agec4.
var labels  mage1 'age of respondent in row cats' mage2 'age of adult 2 in row cats'  mage3 'age of adult 3 in row cats' mage4 'age of adult 4 in row cats'
            magec1 'age of child 1 in row cats' magec2 'age of child 2 in row cats' magec3 'age of child 3 in row cats' magec4 'age of child 4 in rowcats'.

recode mage1 to magec4 (0 thru 17=1) (18 thru 64=2) (65 thru 99=3) (50 thru 64=7) (65 thru 74=8) (75 thru 99=9).

value labels  mage1 to magec4 1 '0-17'  2 '18-64' 3 '65+'.

********************************************************************************************************************************************************************.
comment Page 3: following determines whether respondent is elderly.
********************************************************************************************************************************************************************.
compute eldage = ccage1.
recode eldage (1 thru 4 = 1)(5 thru 6 = 2).
var labels  eldage 'age of respondent'.
value labels eldage 1 '< 65' 2 '65+'.
frequencies eldage.

********************************************************************************************************************************************************************.
comment Page 3: develops an age variable for the head of the household.
********************************************************************************************************************************************************************.
compute headage = ccage1.
if (rel2 eq 2 or rel3 eq 2) headage = ccage2.
variable labels headage 'age  of  hh head'.
value labels  headage 2 '< 35' 3 '35-49' 4 '50-64' 5 '65-74' 6 '75+'.
frequencies ccage1 headage.

********************************************************************************************************************************************************************.
comment Page 3: establishes family categories.
********************************************************************************************************************************************************************.
compute family = 0.
if (hhsiz eq 1 and age1 lt 65 and sex1 eq 1) family = 1.
if ((hhsiz eq 1) and (range(age1,65,74)) and (sex1 eq 1)) family = 2.
if (hhsiz eq 1 and age1 ge 75 and sex1 eq 1) family = 3.
if (hhsiz eq 1 and age1 lt 65 and sex1 eq 2) family = 4.
if (hhsiz eq 1 and range(age1,65,74) and sex1 eq 2) family = 5.
if (hhsiz eq 1 and age1 ge 75 and sex1 eq 2) family = 6.
if (hhsiz eq 2 and rel2 eq 1 and age1 lt 35) family = 7.
if (hhsiz eq 2 and rel2 eq 1 and range(age1,35,49)) family = 8.
if (hhsiz eq 2 and rel2 eq 1 and range(age1,50,64)) family = 9.
if (hhsiz eq 2 and rel2 eq 1 and range(age1,65,74)) family = 10.
if (hhsiz eq 2 and rel2 eq 1 and age1 ge 75) family = 11.
if (hhsiz ge 3 and rel2 eq 1 and range(agec1,0,19)) family = 12.
if (hhsiz ge 4 and rel2 eq 2 and rel3 eq 2 and range(agec1,0,17)) family = 12.
if (hhsiz eq 5 and rel2 eq 2 and rel3 eq 2 and rel4 eq 3 and range(agec1,0,17)) family = 12.
if (hhsiz eq 2 and range(agec1,0,17))family = 13.
if (hhsiz eq 3 and range(agec1,0,17) and rel2 eq 8)family = 13.
if (hhsiz eq 3 and range(agec1,0,17) and range(agec2,0,17))family = 13.
if (hhsiz eq 2 and rel2 eq 5 and sex1 ne sex2) family = 14.
if (hhsiz eq 2 and rel2 eq 5 and sex1 eq sex2) family = 15.
if (hhsiz eq 3 and rel2 eq 1 and rel3 eq 8)family = 16.
if (hhsiz eq 3 and age1 ge 19 and rel2 eq 2 and rel3 eq 2) family = 16.
if (hhsiz eq 4 and rel3 eq 8 and rel4 eq 8)family = 16.
if (hhsiz eq 4 and rel2 eq 2 and rel3 eq 2)family = 16.
if (hhsiz eq 3 and rel2 eq 2 and rel3 eq 2 and range(age1,18,98)) family = 16.
if (hhsiz eq 4 and rel2 eq 2 and rel3 eq 2 and rel4 eq 3)family = 16.
if (hhsiz eq 4 and range(agec1,0,17) and range(agec2,0,17) and range(agec3,0,17)) family = 13.
if (hhsiz eq 2 and rel2 eq 8)family = 17.
if (hhsiz eq 3 and rel2 eq 2 and rel3 eq 8)family = 17.
if (hhsiz eq 4 and rel2 eq 3 and rel3 eq 2 and rel4 eq 3)family = 17.
if (hhsiz eq 3 and rel2 eq 8 and rel3 eq 8)family = 17.
if (hhsiz eq 2 and rel2 eq 2)family = 17.
if (hhsiz eq 2 and rel2 eq 3)family = 18.
if (hhsiz eq 3 and rel2 eq 3 and rel3 eq 3)family = 18.
if (hhsiz eq 3 and rel2 eq 5 and rel3 eq 5)family = 21.
if (hhsiz eq 4 and rel2 eq 5 and rel3 eq 5 and rel4 eq 5) family = 21.
if (hhsiz ge 3 and rel2 eq 5 and range(agec1,0,19) and sex1 ne sex2) family = 22.

value labels family 1 'single male <65' 
	2 'single male 65-74' 		3 'single male 75+'			4 'single female <65' 		5 'single female 65-74' 
	6 'single female 75+'  		7 'married couple < 35'			8 'married couple 35-49' 		9 'married couple 50-64' 
	10 'married couple 65-74' 	11 'married 75+'				12 'married couple w-kids'  	13 'single parent' 
	14 'posslq'  			15 'same sex couple-roommates'		16 'mar coup adult child' 		17 'single parent w adult child' 
	18 'siblings' 			19 'adult w eld parent'			20 'sandwich' 			21 'roomates' 		
	22 'unmarried couple w kids' 	23 'married cple adult child eld parent' 	24 'unmarried couple with adult child' 
	25 'single parent w elderly parent' 					26 'siblings with eld parent and child'	
	27 'cousins with kids' 		28 'married couple with eld parent' 	29 'siblings' 			30 'cousins'. 
frequencies family.

temporary.
select if family eq 0.
frequencies id.

comment deals with specific cases.
if any(id,33) family =  12.
if any(id,47,285,242) family = 16 .
if any(id,611) family = 17 .
if any(id,165) family = 13 .
if any(id,591) family = 4 .

frequencies family.

compute cfamily = family.
recode cfamily (1,4=103) (2,3,5,6=105) (7,8,9= 102)(10,11=104)
   (12,13=101)(20, 22, 25, 26, 27= 101) (else = 106).
value labels cfamily 103 'non-eld single' 105 'eld     single' 102 'non-eld couple' 
  104 'eld     couple'    101 'hh with kids' 106 'other'.
missing values cfamily (99).
frequencies cfamily.

compute jhhc = 2.
if (cfamily eq 101) and ( (any(cjc1,1,3)) or (any(cjc2,1,3)) or (any(cjc3,1,3)) or (any(cjc4,1,3)) ) jhhc = 1.
if (cfamily ne 101) jhhc = 3.
variable labels jhhc 'jewish household with children'.
value labels jhhc 1 'yes' 2 'no' 3 'not a hh with children'.
missing values jhhc (3).
frequencies jhhc.

********************************************************************************************************************************************************************.
comment Page 3: compute number of persons.
comment remember to write id specific statements to deal with adults in kids spots.
********************************************************************************************************************************************************************.
compute nchild = 0.
if range(agec1,0,17) nchild = nchild + 1.
if range(agec2,0,17) nchild = nchild + 1.
if range(agec3,0,17) nchild = nchild + 1.
if range(agec4,0,17) nchild = nchild + 1.

compute njchild = 0.
if (range(agec1,0,17) and any(cjc1,1,3))  njchild = njchild + 1.
if (range(agec2,0,17) and any(cjc2,1,3))  njchild = njchild + 1.
if (range(agec3,0,17) and any(cjc3,1,3))  njchild = njchild + 1.
if (range(agec4,0,17) and any(cjc4,1,3))  njchild = njchild + 1.

compute njchild5 = 0.
if (range(agec1,0,5) and any(cjc1,1,3))  njchild5 = njchild5 + 1.
if (range(agec2,0,5) and any(cjc2,1,3))  njchild5 = njchild5 + 1.
if (range(agec3,0,5) and any(cjc3,1,3))  njchild5 = njchild5 + 1.
if (range(agec4,0,5) and any(cjc4,1,3))  njchild5 = njchild5 + 1.
variable labels njchild5 'Number of Preschool/Child Care Age Kids'.
frequencies njchild5.

compute nchild12 = 0.
if range(agec1,0,12) nchild12 = nchild12 + 1.
if range(agec2,0,12) nchild12 = nchild12 + 1.
if range(agec3,0,12) nchild12 = nchild12 + 1.
if range(agec4,0,12) nchild12 = nchild12 + 1.

compute njch12 = 0.
if (range(agec1,0,12) and any(cjc1,1,3)) njch12 = njch12 + 1.
if (range(agec2,0,12) and any(cjc1,1,3)) njch12 = njch12 + 1.
if (range(agec3,0,12) and any(cjc1,1,3))  njch12 = njch12 + 1.
if (range(agec4,0,12 )and any(cjc4,1,3))  njch12 = njch12 + 1.

compute nteen = 0.
if (range(agec1,13,17)) nteen = nteen + 1.
if (range(agec2,13,17)) nteen = nteen + 1.
if (range(agec3,13,17)) nteen = nteen + 1.
if (range(agec4,13,17)) nteen = nteen + 1.

compute njteen = 0.
if (range(agec1,13,17) and any(cjc1,1,3)) njteen = njteen + 1.
if (range(agec2,13,17) and any(cjc2,1,3)) njteen = njteen + 1.
if (range(agec3,13,17) and any(cjc3,1,3)) njteen = njteen + 1.
if (range(agec4,13,17) and any(cjc4,1,3)) njteen = njteen + 1.

compute nadult = 1.
if range(rel2,0,9) nadult = nadult + 1.
if range(rel3,0,9) nadult = nadult + 1.
if range(rel4,0,9) nadult = nadult + 1.

compute nelder65 = 0.
if range(age1,65,99) nelder65 = nelder65 + 1.
if range(age2,65,99) nelder65 = nelder65 + 1.
if range(age3,65,99) nelder65 = nelder65 + 1.
if range(age4,65,99) nelder65 = nelder65 + 1.

compute nelder75 = 0..
if range(age1,75,99) nelder75 = nelder75 + 1.
if range(age2,75,99) nelder75 = nelder75 + 1.
if range(age3,75,99) nelder75 = nelder75 + 1.
if range(age4,75,99) nelder75 = nelder75 + 1.

compute nsing2 = nsing.
recode nsing2 (1 thru 9 = 1).
recode nsing2 (0=2).
variable labels nsing2 'Any Single Person in Household Age 18-64'.
value labels nsing2 1 'Yes' 2 'No'.

compute nelder2 = nelder65.
recode nelder2 (1 thru 9 = 1).
recode nelder2 (0=2).
variable labels nelder2 'Any Elderly Person in Household'.
value labels nelder2 1 'Yes' 2 'No'.
frequencies nelder65.

comment identifies households with child respondents or adults in the children's columns.
temporary.
select if age1 lt 18 or age2 lt 18 or age3 lt 18 or age4 lt 18.
frequencies id.

temporary.
select if agec1 gt 17 or agec2 gt 17 or agec3 gt 17 or agec4 gt 17.
frequencies id.

variable labels nchild 'number of children in household' njchild 'number of jewishchildren in household' nchild12 'number of children age 12 and under'
		njch12 'number of jewish children age 12 and under' nteen 'number of teens in household' njteen 'number of jewish teens in household'
                	nelder65 'number of persons age 65+'  nelder75 'number of persons age 75+'  nadult 'number of adults in household'.
frequencies nchild njchild nchild12 njch12 nteen njteen nelder65 nelder75 nadult.

********************************************************************************************************************************************************************.
comment page 3: geography categories.
********************************************************************************************************************************************************************.
if (born1 eq 1) lbefore = 1.
compute cborn1=born1.
compute cborn2=born2.
compute cborn3=born3.
compute cborn4=born4.
compute cbornc1=bornc1.
compute cbornc2=bornc2.
compute cbornc3=bornc3.
compute cbornc4=bornc4.
compute clbefor = lbefore.

var labels clbefor 'place of previous residence' cborn1 'birthplace-respondent' cborn2 'birthplace-adult 2' cborn3 'birthplace-adult 3'
           cborn4 'birthplace-adult 4' cbornc1 'birthplace-child 1' cbornc2 'birthplace-child 2'  cbornc3 'birthplace-child 3'  cbornc4 'birthplace-child 4'.

comment remember to adjust below for new geography (done in Hartford).

recode cborn1 cborn2 cborn3 cborn4 cbornc1 cbornc2 cbornc3 cbornc4 clbefor 
 (1 2 3 = 100) (5 6 7 8 9 29 36 42 48 54 = 101) (10 12 13 24 25 26 30 32 34 39 44 52 = 102) (11 14 17 20 21 27 28 31 38 40 43 45 46 49 51 = 103)
 (15 16 18 19 22 23 33 35 37 41 47 50 53 = 104) (69 70 71 72 76 77 78 = 105) (66 67 68 73 74 75 = 106) (55=109)  (58=110) (56 57 = 107) (60 61 62 = 108).

value labels cborn1 cborn2 cborn3 cborn4 cbornc1 cbornc2 cbornc3 cbornc4 clbefor 100 'Connecticut'  101 'other northeast' 102 'midwest' 
	103 'south' 104 'west' 105 'eastern europe' 106 'western europe' 109 'canada' 107 'south-mid america' 108 'middle east' 110 'rsa' 64 'Asia'.
frequencies born1 cborn1 cborn2 cborn3 cborn4.

********************************************************************************************************************************************************************.
comment page 3: computes conversion.
********************************************************************************************************************************************************************.
if (bj1 eq 2 and cj1 eq 1)conv1 = 1.
if (bj2 eq 2 and cj2 eq 1)conv2 = 1.
if (bj3 eq 2 and cj3 eq 1)conv3 = 1.
if (bj4 eq 2 and cj4 eq 1)conv4 = 1.
if (bjc1 eq 2 and cjc1 eq 1)convc1 = 1.
if (bjc2 eq 2 and cjc2 eq 1)convc2 = 1.
if (bjc3 eq 2 and cjc3 eq 1)convc3 = 1.
if (bjc4 eq 2 and cjc4 eq 1)convc4 = 1.

recode conv1 (sysmis = 2).
recode conv2 conv3 conv4 convc1 convc2 convc3 convc4 (sysmis = 999).
if (range(age2,1,99) and conv2 ne 1) conv2 = 2.
if (range(age3,1,99) and conv3 ne 1) conv3 = 2.
if (range(age4,1,99) and conv4 ne 1) conv4 = 2.
if (range(agec1,0,99) and convc1 ne 1) convc1 = 2.
if (range(agec2,0,99) and convc2 ne 1) convc2 = 2.
if (range(agec3,0,99) and convc3 ne 1) convc3 = 2.
if (range(agec4,0,99) and convc4 ne 1) convc4 = 2.
recode conv2 conv3 conv4 convc1 convc2 convc3 convc4 (999 = sysmis).
value labels conv1 conv2 conv3 conv4 convc1 convc2 convc3 convc4 1 'a convert' 2 'not a convert' .

compute nconv1 =conv1.
compute nconv2 =conv2.
compute nconv3 =conv3.
compute nconv4 =conv4.
compute nconvc1 =convc1.
compute nconvc2 =convc2.
compute nconvc3 =convc3.
compute nconvc4 =convc4.

if (cj1 ne 1) nconv1 = 3.
if (cj2 ne 1) nconv2 = 3.
if (cj3 ne 1) nconv3 = 3.
if (cj4 ne 1) nconv4 = 3.

if (cjc1 ne 1) nconvc1 = 3.
if (cjc2 ne 1) nconvc2 = 3.
if (cjc3 ne 1) nconvc3 = 3.
if (cjc4 ne 1) nconvc4 = 3.

variable labels nconv1 'New Conversion Variable, pulling non-Jews Out of not a convert category'
 		nconv2 'New Conversion Variable, pulling non-Jews Out of not a convert category'
		nconv3 'New Conversion Variable, pulling non-Jews Out of not a convert category'
 		nconv4 'New Conversion Variable, pulling non-Jews Out of not a convert category'
 		nconvc1 'New Conversion Variable, pulling non-Jews Out of not a convert category'
 		nconvc2 'New Conversion Variable, pulling non-Jews Out of not a convert category'
		nconvc3 'New Conversion Variable, pulling non-Jews Out of not a convert category'
 		nconvc4 'New Conversion Variable, pulling non-Jews Out of not a convert category'.
value lables nconv1 nconv2 nconv3 nconv4 nconvc1 nconvc2 nconvc3 nconvc4 1 'A Convert' 2 'Not a Convert' 3 'Not Jewish'.
frequencies conv1 to convc4 nconv1 to nconvc4.

comment the following figures out if a spouse of respondent is ever in position 3 or 4.
temporary.
select if rel3 eq 1 or rel4 eq 1..
frequencies id.

********************************************************************************************************************************************************************.
comment Page 3: computes intermarriage.
********************************************************************************************************************************************************************.
compute inter = 0.

comment covers if adult 1 and 2 are married and if adult 2 and 3 are  parents.

comment following is an inmarriage.
if (rel2 eq 1 and cj1 eq 1 and cj2 eq 1 and bj1 eq 1 and bj2 eq 1)inter=1.
if (rel2 eq 2 and rel3 eq 2 and cj2 eq 1 and cj3 eq 1 and bj2 eq 1 and bj3 eq 1) inter = 1.

comment following is a conversionary inmarriage.
if (rel2 eq 1 and (conv1 eq 1 or conv2 eq 1)) inter = 2.
if (rel2 eq 2 and rel3 eq 2 and conv2 eq 1 or conv3 eq 1) inter = 2.

comment following is an intermarriage.
if (rel2 eq 1 and cj1 ne cj2)inter=3.
if (rel2 eq 2 and rel3 eq 2 and cj2 ne cj3)inter = 3.

comment example to cover any special case: if any(id,555) inter = 1.

var labels inter 'intermarriage'.
value labels inter 1 'inmarriage' 2 'conversionary' 3 'intermarriage'.
missing values inter (0).

frequencies inter.


********************************************************************************************************************************************************************.
comment Page 3: is all everyone in hh jewish.
********************************************************************************************************************************************************************.
compute all_jews = 1.
if (cj1 eq 2 or cj2 eq 2 or cj3 eq 2 or cj4 eq 2 or cjc1 eq 2 or cjc2 eq 2 or cjc3 eq 2 or cjc4 eq 2) all_jews = 2.
var labels all_jews 'everyone in hh is jewish'.
value labels all_jews 1 'yes' 2 'no'.
frequencies all_jews.

********************************************************************************************************************************************************************.
comment Page 3: what is sex of intermarrying persons.
********************************************************************************************************************************************************************.

compute sexnj = 0.
if (inter eq 3 and rel2 eq 1 and bj1 eq 2 and sex1 eq 1) sexnj = 1.
if (inter eq 3 and rel2 eq 1 and bj1 eq 2 and sex1 eq 2) sexnj = 2.
if (inter eq 3 and rel2 eq 1 and bj2 eq 2 and sex2 eq 1) sexnj = 1.
if (inter eq 3 and rel2 eq 1 and bj2 eq 2 and sex2 eq 2) sexnj = 2.
if (inter eq 3 and rel2 eq 2 and bj2 eq 2 and sex2 eq 1) sexnj = 1.
if (inter eq 3 and rel2 eq 2 and bj2 eq 2 and sex2 eq 2) sexnj = 2.
if (inter eq 3 and rel2 eq 2 and bj3 eq 2 and sex3 eq 1) sexnj = 1.
if (inter eq 3 and rel2 eq 2 and bj3 eq 2 and sex3 eq 2) sexnj = 2.
if (inter eq 2 and rel2 eq 1 and bj1 eq 2 and sex1 eq 1) sexnj = 1.
if (inter eq 2 and rel2 eq 1 and bj1 eq 2 and sex1 eq 2) sexnj = 2.
if (inter eq 2 and rel2 eq 1 and bj2 eq 2 and sex2 eq 1) sexnj = 1.
if (inter eq 2 and rel2 eq 1 and bj2 eq 2 and sex2 eq 2) sexnj = 2.
if (inter eq 2 and rel2 eq 2 and bj2 eq 2 and sex2 eq 1) sexnj = 1.
if (inter eq 2 and rel2 eq 2 and bj2 eq 2 and sex2 eq 2) sexnj = 2.
if (inter eq 2 and rel2 eq 2 and bj3 eq 2 and sex3 eq 1) sexnj = 1.
if (inter eq 2 and rel2 eq 2 and bj3 eq 2 and sex3 eq 2) sexnj = 2.
var labels sexnj 'sex of jew who intermarried'.
value labels sexnj 1 'male nj' 2 'female nj'.

frequencies sexnj. 

********************************************************************************************************************************************************************.
comment Page 4: latch key children  1st-married with kids 2nd-single parent.
********************************************************************************************************************************************************************.
if (family eq 12) latch = 3.
if (latch eq 3 and emp1 eq 1 and emp2 eq 1) latch = 1.

if (family eq 13) latch = 3.
if (latch eq 3 and emp1 eq 1) latch = 1.

if (latch eq 1 and range(nchild12,1,4)) latch = 2.
var labels latch is household a latchkey household.
value labels latch 1 'latch no < age 12' 2 'latch < age 12' 3 'not latch'.
frequencies latch.
********************************************************************************************************************************************************************.
comment Page 4: degree categorization.
********************************************************************************************************************************************************************.

compute cdeg1=deg1.
compute cdeg2=deg2.
compute cdeg3=deg3.
compute cdeg4=deg4.

var labels cdeg1 'cat degree level for respondent'
           cdeg2 'cat degree level for adult 2'
           cdeg3 'cat degree level for adult 3'
           cdeg4 'cat degree level for adult 4'.

recode cdeg1 cdeg2 cdeg3 cdeg4 (1 = 100) (2 3 4 = 101) (5 = 102) (6 7 = 103) (8 9 10 11 12 13 14 = 104).

value labels cdeg1 cdeg2 cdeg3 cdeg4 100 'no degree'  101 'high school deg'
   102 'grad 2-yr college' 103 'grad 4-yr college' 104 'grad degree'.
frequencies cdeg1.

compute sing= 0.
if (needsing eq 2) sing = 1.
if (needsing eq 1 and recsing eq 2) sing = 2.
if (needsing eq 1 and recsing eq 1 and jrecsing eq 1) sing = 3.
if (needsing eq 1 and recsing eq 1 and jrecsing eq 2) sing = 4.
var labels sing 'combined singles variable'.
value labels sing 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.
missing values sing (0).
frequencies sing.

********************************************************************************************************************************************************************.
comment Page 4: Marital categorization
********************************************************************************************************************************************************************.
comment these two statements are here because they would not run below where they belong.
value labels cmar1 cmar2 cmar3 cmar4 100 'Now     Married'  101 'Widowed' 102 'Divorced' 103 'Single  Never Married'.

compute divor_hh = 2.
if (any(mar1,2,5) or any(mar2,2,5) or any(mar3,2,5) or any(mar4,2,5)) divor_hh = 1.
variable labels divor_hh   'Divorced Person in Household'.
value labels divor_hh	1 'Yes' 	2 'No'.


recode mar1 mar2 mar3 mar4 (1.5 = 4).
frequencies variables = mar1 mar2 mar3 mar4.

compute cmar1 = mar1.
compute cmar2 = mar2.
compute cmar3 = mar3.
compute cmar4 = mar4.
var labels cmar1 'cat marital status for respondent'
           cmar2 'cat marital status for adult 2'
           cmar3 'cat marital status for adult 3'
           cmar4 'cat marital status for adult 4'.

recode  cmar1 cmar2 cmar3 cmar4 (1 2 3 7 = 100) (6=101) (5=102) (4, 1.5=103).

comment singles needs.

********************************************************************************************************************************************************************.
comment Page 5: Adult Children Programming.
********************************************************************************************************************************************************************.
compute interkid = acmar - acmarj.
frequencies interkid.
variable labels interkid 'Number of Intermarried Adult Children'.
frequencies ac wac acmar acmarj interkid grandno.

if (ac eq 0) aclocal = 0.
if (range(wac,1,8)) aclocal = 1.
if (wac eq 0) aclocal = 2.
variable labels aclocal 'One or More Adult Children Live in Local Area'.
value labels aclocal    0 'No Adult Kids Who Have Established Own Homes'   1 'Adult Child in Local Area'    2 'No Local Adult Child'   .
frequencies ac wac aclocal.

compute numac = ac-wac.
frequencies ac wac numac.

if (id eq 370) ac = 2.

frequencies givecare.
compute eldcare=givecare.
recode eldcare (2=102).
if (eldcare eq 1 and live100 eq 1) eldcare = 103.
if (eldcare eq 1 and live100 eq 2) eldcare = 104.
variable labels eldcare 'Combined Care for Elderly Parent'.
value lables eldcare 102 'No Elderly Care Given' 103 'Relative Care for Lives within 100 Miles'   104 'Relative Cared For Lives Beyond 100 Miles'.
frequencies eldcare.

********************************************************************************************************************************************************************.
comment Page 6: Adult jewish education changes.
********************************************************************************************************************************************************************.
compute ajed = 2.
if ((ajed1 eq 4) or (ajed2 eq 4) or (ajed3 eq 4) or (ajed4 eq 4)) ajed = 1.
var labels ajed 'any adult to jewish day school'.
value labels ajed 2 'None to Day School' 1 'Someone to Day School'.
frequencies ajed.

*************************************************.
COMMENT CREATES INFORMAL JEWISH ED VARIABLES.
*************************************************.

COMPUTE SLEEP = 2.
IF ((SLEEP1 EQ 1) OR (SLEEP2 EQ 1) OR (SLEEP3 EQ 1) OR (SLEEP4 EQ 1)) SLEEP = 1.
VAR LABELS SLEEP 'ANY ADULT TO JEWISH SLEEP AWAY CAMP'.
VALUE LABELS SLEEP 2 'None to Sleep Away' 1 'Someone to Sleep Away Camp'.
frequencies sleep.

COMPUTE YG = 2.
IF ((YG1 EQ 1) OR (YG2 EQ 1) OR (YG3 EQ 1) OR (YG4 EQ 1)) YG = 1.
VAR LABELS YG 'ANY ADULT PARTICIPANT IN YOUTH GROUP'.
VALUE LABELS YG  1 'Someone to Youth Group' 2 'None to Youth Group'.

COMPUTE HILLEL = 2.
IF (ANY(DEG1,1,2,3)) HILLEL1 =  3.
IF (nadult ge 2 and ANY(DEG2,1,2,3)) HILLEL2 =  3.
IF (nadult ge 3 and ANY(DEG3,1,2,3)) HILLEL3 =  3.
IF (nadult ge 4 and ANY(DEG4,1,2,3)) HILLEL4 =  3.

IF ((NADULT EQ 1) AND (HILLEL1 EQ 3)) HILLEL = 3.
IF (NADULT EQ 2 AND (HILLEL1 EQ 3 AND HILLEL2 EQ 3)) HILLEL = 3.
IF (NADULT EQ 3 AND (HILLEL1 EQ 3 AND HILLEL2 EQ 3 AND HILLEL3 EQ 3)) HILLEL = 3.
IF (NADULT GE 4 AND (HILLEL1 EQ 3 AND HILLEL2 EQ 3 AND HILLEL3 EQ 3 AND HILLEL4 EQ 3)) HILLEL = 3.

IF ((HILLEL1 EQ 1) OR (HILLEL2 EQ 1) OR (HILLEL3 EQ 1) OR (HILLEL4 EQ 1)) HILLEL = 1.
VAR LABELS HILLEL 'ANY ADULT PARTICIPANT IN HILLEL'.
VALUE LABELS HILLEL1 HILLEL2 HILLEL3 HILLEL4 1 'To Hillel' 2 'Not to Hillel' 3 'Never in College'.
VALUE LABELS HILLEL 1 'Someone to Hillel' 2 'None to Hillel'  3 'None to College'.

frequencies sleep yg hillel.

********************************************************************************************************************************************************************.
comment Page 7: Religiosity Changes.
********************************************************************************************************************************************************************.
compute cocr = ocr.
recode cocr (4=2) (7,8=5).
var labels cocr 'jewish identification'.
value labels cocr 1 'Orthodox' 2 'Conservative' 3 'Reform' 4 'Reconstructionist' 5 'Just Jewish'.

compute jsex = sex1.
if (cj1 ne 1 and rel2 eq 1) jsex = sex2.
var labels jsex 'sex of jewish hh'.
value labels jsex 1 'male' 2 'female'.

recode kosher (2=3).
if (inout eq 2) kosher = 2.
if (inout eq 1) kosher = 1.
value labels kosher 1 'in home' 2 'in-out' 3 'no'.
frequencies kosher.

if (kosher eq 3) lights = 1.
if (inout eq 1) lights = 1.

compute practice = 2.
compute pracmezz = 2.
if any(hancan,1,2) practice = 1.
if any(seder,1,2) practice = 1.
if any(fcan,1,2) practice = 1.
if any(kosher,1) practice = 1.

compute pracmezz = practice.
if (mezz eq 1) pracmezz = 1.
var labels practice 'always-usu light chan-sabbath-seder-kosher'/
           pracmezz 'adds mezuzah to list of observances'.

compute assoc = 2.
if (synmem eq 1) assoc eq 1.
if (member eq 1) assoc eq 1.
if (jccmem eq 1) assoc eq 1.

compute pracgive = 2.
compute pracasso = 2.
compute assocgiv = 2.
compute alljew = 2.
if (jchar eq 1 or practice eq 1) pracgive = 1.
if (assoc eq 1 or practice eq 1) pracasso = 1.
if (assoc eq 1 or jchar eq 1 or any(jfed,1,3,4,5,6)) assocgiv = 1.
if (assoc eq 1 or jchar eq 1 or practice eq 1 or any(jfed,1,3,4,5,6)) alljew = 1.

variable labels
   assoc 'belong to something jewish'/
   pracgive 'always-usual practice something or give'/
   pracasso 'belong to something or practice'/
   assocgiv 'belong to something or give'/
   alljew 'do something jewish'.
value labels assoc pracgive pracasso assocgiv alljew practice pracmezz   1 'yes' 2 'no'.
frequencies alljew.

********************************************************************************************************************************************************************.
comment Page 8: Disability changes
********************************************************************************************************************************************************************.

recode cdis (2=3).
if (csup eq 1) cdis = 2.

recode dis (2=3).
if (sup eq 1) dis eq 2.

compute totdis = 3.
if (dis eq 1 or cdis eq 1) totdis = 1.
if (dis eq 2 or cdis eq 2) totdis = 2.

value labels dis cdis totdis 1 'disabled-no daily assistance' 2 'disabled-need daily assistance' 3 'not disabled'.

frequencies dis cdis totdis supwk.

recode around to appear (sysmis = 999).
frequencies around.
if (any(dis,1,2) and bath eq 999) bath = 2.
if (any(dis,1,2) and around eq 999) around = 2.
if (any(dis,1,2) and eat eq 999) eat = 2.
if (any(dis,1,2) and dress eq 999) dress = 2.
if (any(dis,1,2) and elim eq 999) elim = 2.
if (any(dis,1,2) and appear eq 999) appear = 2.
recode around to appear (999 = sysmis).
frequencies around to dkadl.

compute numadl = 0.
if (around eq 1) numadl = numadl + 1.
if (eat eq 1) numadl = numadl + 1.
if (dress eq 1) numadl = numadl + 1.
if (bath eq 1) numadl = numadl + 1.
if (elim eq 1) numadl = numadl + 1.
if (appear eq 1) numadl = numadl + 1.
frequencies numadl.
variable labels numadl 'Number of ADLs that Person Has Trouble With'.

comment any adl problem. 
if (around eq 1 or eat eq 1 or dress eq 1 or bath eq 1 or elim eq 1 or appear eq 1) adl = 1.
recode adl (sysmis =  2).
variable labels adl 'ADLs'.
value labels adl 1 'Has Problem with At Least One ADL' 2 'Has no Problem'.
frequencies adl.


********************************************************************************************************************************************************************.
comment Page 8: Needs Variables.
********************************************************************************************************************************************************************.

compute coun = 0.
if (needcoun eq 2) coun = 1.
if (needcoun eq 1 and reccoun eq 2) coun = 2.
if (needcoun eq 1 and reccoun eq 1 and jreccoun eq 1) coun = 3.
if (needcoun eq 1 and reccoun eq 1 and jreccoun eq 2) coun = 4.
var labels coun 'combined counseling variable'.
value labels coun 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

compute job = 0.
if (needjob eq 2) job = 1.
if (needjob eq 1 and recjob eq 2) job = 2.
if (needjob eq 1 and recjob eq 1 and jrecjob eq 1) job = 3.
if (needjob eq 1 and recjob eq 1 and jrecjob eq 2) job = 4.
var labels job 'combined job variable'.
value labels job 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

missing values coun job (0).
frequencies coun job.

********************************************************************************************************************************************************************.
comment Page 10: child jewish education changes.
********************************************************************************************************************************************************************.

if (school1 eq 3 or school2 eq 3 or school3 eq 3 or school4 eq 3) consider = 5.
add value labels consider 5 'child now in day school'.

recode fjed1 fjed2 fjed3 fjed4 (9=3).

comment make ever jewish education a yes if is in day school.
if (school1 eq 3)cjed1 eq 1.
if (school2 eq 3)cjed2 eq 1.
if (school3 eq 3)cjed3 eq 1.
if (school4 eq 3)cjed4 eq 1.

compute chldjed1 = 0.
compute chldjed2 = 0.
compute chldjed3 = 0.
compute chldjed4 = 0.

if any(cjed1,1,3) chldjed1 = 1.
if any(cjed2,1,3) chldjed2 = 1.
if any(cjed3,1,3) chldjed3 = 1.
if any(cjed4,1,3) chldjed4 = 1.
if (cjed1 eq 2 and any(fjed1,1,2))chldjed1 = 2.
if (cjed2 eq 2 and any(fjed2,1,2))chldjed2 = 2.
if (cjed3 eq 2 and any(fjed3,1,2))chldjed3 = 2.
if (cjed4 eq 2 and any(fjed4,1,2))chldjed4 = 2.
if (cjed1 eq 2 and any(fjed1,3,4))chldjed1 = 3.
if (cjed2 eq 2 and any(fjed2,3,4))chldjed2 = 3.
if (cjed3 eq 2 and any(fjed3,3,4))chldjed3 = 3.
if (cjed4 eq 2 and any(fjed4,3,4))chldjed4 = 3.
var labels chldjed1 'child 1 ever go to jewish education'
           chldjed2 'child 2 ever go to jewish education'
           chldjed3 'child 3 ever go to jewish education'
           chldjed4 'child 4 ever go to jewish education'.
value labels chldjed1 chldjed2 chldjed3 chldjed4 1 'has had or in j ed'
          2 'not yet but def or prob will'  3 'has never and will not'.
missing values chldjed1 to chldjed4 (0).
frequencies chldjed1 to chldjed4.

comment creates and age variable that collapses the few five year olds in kindergarten into the 6-12 year olds.
compute sagec1a = sagec1.
compute sagec2a = sagec2.
compute sagec3a = sagec3.
compute sagec4a = sagec4.
recode sagec1a to sagec4a (1=2).
value labels sagec1a to sagec4a 2 '6-12' 3 '13-17'.
missing values sagec1a to sagec4a (4).

recode costed to phil (sysmis = 999).
if (any(consider,1,2) and costed eq 999) costed = 2.
if (any(consider,1,2) and dist eq 999) dist = 2.
if (any(consider,1,2) and quale eq 999) quale = 2.
if (any(consider,1,2) and extra eq 999) extra = 2.
if (any(consider,1,2) and interm eq 999) interm = 2.
if (any(consider,1,2) and notrel eq 999) notrel = 2.
if (any(consider,1,2) and relig eq 999) relig = 2.
if (any(consider,1,2) and public eq 999) public = 2.
if (any(consider,1,2) and qoth eq 999) qoth = 2.
if (any(consider,1,2) and length eq 999) length = 2.
if (any(consider,1,2) and ldised eq 999) ldised = 2.
if (any(consider,1,2) and phil eq 999) phil = 2.
recode costed to phil (999 = sysmis).

********************************************************************************************************************************************************************.
comment Page 11: israel transformations.
********************************************************************************************************************************************************************.
comment any child or any any adult has been to Israel.
compute anyisr = 100.
if (any(goisr,5) or any(goisrc,5)) anyisr = 101.
if (any(goisr,3,4,6) or any(goisrc,3,4,6)) anyisr = 102.

var labels anyisr 'anyone in household to israel and how'.
value labels anyisr 100 'no one in household to israel' 101  'general trip' 102  'jewish trip' .
frequencies anyisr.

comment any adult been to Israel.
compute cgoisr = 100.
if any(goisr,3,4,6) cgoisr = 102.
if any(goisr,5) cgoisr = 101.
variable labels cgoisr 'Some Adult in Household to Israel'.
value labels cgoisr 100 'No one to Israel' 101 'General Trip' 102 'Jewish Trip'.
frequencies cgoisr.

recode safety to work (sysmis = 999).

if ((any(teenisr,1,2,3)) and tcost eq 999) tcost = 2.
if ((any(teenisr,1,2,3)) and tdist eq 999) tdist = 2.
if ((any(teenisr,1,2,3)) and cni eq 999) cni= 2.
if ((any(teenisr,1,2,3)) and pni eq 999) pni = 2.
if ((any(teenisr,1,2,3)) and safety eq 999) safety = 2.
if ((any(teenisr,1,2,3)) and mature eq 999) mature = 2.
if ((any(teenisr,1,2,3)) and work eq 999) work = 2.
if ((any(teenisr,1,2,3)) and ss eq 999) ss = 2.
if ((any(teenisr,1,2,3)) and friend2 eq 999) friend2 = 2.
if ((any(teenisr,1,2,3)) and tdk eq 999) tdk = 2.
if ((any(teenisr,1,2,3)) and toth eq 9) toth = 2.


recode safety to work (999=sysmis).
frequencies safety to work.

********************************************************************************************************************************************************************.
comment Page 12: Childrens Needs Variables.
********************************************************************************************************************************************************************.
compute ldis = 0.
if (needis eq 2) ldis = 1.
if (needis eq 1 and recdis eq 2) ldis = 2.
if (needis eq 1 and recdis eq 1) ldis = 3.
var labels ldis 'combined learning disabled variable'.
value labels ldis 1 'no need' 2 'need-no rec' 3 'need-rec'.

missing values  ldis (0).
frequencies ldis.

comment children's general disability done above with adults.

********************************************************************************************************************************************************************.
comment Page 13: Elderly Needs Variables.
********************************************************************************************************************************************************************.

compute hh= 0.
if (needhh eq 2) hh = 1.
if (needhh eq 1 and rechh eq 2) hh = 2.
if (needhh eq 1 and rechh eq 1 and jrechh eq 1) hh = 3.
if (needhh eq 1 and rechh eq 1 and jrechh eq 2) hh = 4.
var labels hh 'combined home health care variable'.
value labels hh 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

compute sday= 0.
if (needsday eq 2) sday = 1.
if (needsday eq 1 and recsday eq 2) sday = 2.
if (needsday eq 1 and recsday eq 1 and jrecsday eq 1) sday = 3.
if (needsday eq 1 and recsday eq 1 and jrecsday eq 2) sday = 4.
var labels sday 'combined senior day care variable'.
value labels sday 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

compute meal = 0.
if (needmeal eq 2) meal = 1.
if (needmeal eq 1 and recmeal eq 2) meal = 2.
if (needmeal eq 1 and recmeal eq 1 and jrecmeal eq 1) meal = 3.
if (needmeal eq 1 and recmeal eq 1 and jrecmeal eq 2) meal = 4.
var labels meal 'combined meal on wheels variable'.
value labels meal 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

compute tran= 0.
if (needtran eq 2) tran = 1.
if (needtran eq 1 and rectran eq 2) tran = 2.
if (needtran eq 1 and rectran eq 1 and jrectran eq 1) tran = 3.
if (needtran eq 1 and rectran eq 1 and jrectran eq 2) tran = 4.
var labels tran 'combined transportation variable'.
value labels tran 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

compute nurs= 0.
if (neednurs eq 2) nurs = 1.
if (neednurs eq 1 and recnurs eq 2) nurs = 2.
if (neednurs eq 1 and recnurs eq 1 and jrecnurs eq 1) nurs = 3.
if (neednurs eq 1 and recnurs eq 1 and jrecnurs eq 2) nurs = 4.
var labels nurs 'combined nursing home variable'.
value labels nurs 1 'no need' 2 'need-no rec' 3 'recvd-j' 4 'recvd-nj'.

missing values  hh sday meal  tran  nurs ldis (0).

frequencies hh to nurs.
********************************************************************************************************************************************************************.
comment Page 14: Membership changes.
********************************************************************************************************************************************************************.
recode eversyn (9=2).
recode synmem (9=2).
recode besyn (9=3).

compute syn = 0.
if (synmem eq 1) syn = 1.
if (synmem eq 2 and eversyn eq 1 and any(besyn,1,2))syn = 2.
if (synmem eq 2 and eversyn eq 1 and any(besyn,3,4))syn = 3.
if (synmem eq 2 and eversyn eq 2 and any(besyn,1,2))syn = 4.
if (synmem eq 2 and eversyn eq 2 and any(besyn,3,4))syn = 5.
var labels syn 'synagogue membership'.
value labels syn 1 'current members' 2 'in past, again in future' 3 'in past, not in future' 
   4 'never, but will be' 5 'never, never will be'.
missing values syn(0).
frequencies syn.

frequencies jccmem part.
if (jccmem eq 1) part eq 1.
frequencies part.

********************************************************************************************************************************************************************.
comment Page 15: Charity Changes.
********************************************************************************************************************************************************************.

recode jchar njchar cont jfed (9=2).
 
if any(jfed,2,9) amtfed = 0.

frequencies jfed.
compute donate = 0.
if (cont eq 1) donate = 2.
if (cont eq 2) donate = 3.
if any(jfed,4,1) donate = 1.

compute cjfed = jfed.
recode cjfed (3,4 = 1).
variable labels cjfed 'Combined Donate to Federation'.
value labels cjfed 1 'Give either in Hartford or Elsewhere' 2 'Non-giver'.
frequencies jfed cjfed.


value labels donate 1 'donated' 2 'asked, did not donate' 3 'not asked'.
var labels donate 'donation market segments'.
missing values donate (0).
frequencies donate cont.

temporary.
select if donate eq 0.
frequencies id.
if any(id,16,278,291,348) donate = 3.

if (jchar ne 1) jchar1 =0.
compute cjchar1=jchar1.
recode cjchar1 (4 thru 8=4).
var labels cjchar1 'giving to other jew char with collapsed cat'.
value labels cjchar1 0 'nothing' 1 '< $100' 2 '$100- 500' 3 '$500-1,000' 4 '$1000+' 9 'dk-nr'.

if (njchar ne 1) njchar1 =0.
compute cnjchar1=njchar1.
recode cnjchar1 (4 thru 8=4).
var labels cnjchar1 'give to all nj char w-collapsed cat'.
value labels cnjchar1 0 'nothing' 1 '< $100' 2 '$100-500' 3 '$500-1,000' 4 '$1000+' 9 'dk-nr'.

compute camtfed=amtfed.
recode camtfed (4 thru 8 =4).
var labels camtfed 'giving to local federation'.
value labels camtfed 0 'nothing' 1 '$<$100' 2 '$100-500' 3 '$500-1000' 4 '$1000 +' 9 'dk-nr'.

compute ccamtfed=camtfed.
recode ccamtfed (2 thru 4 =2).
var labels ccamtfed 'giving to local federation'.
value labels ccamtfed 0 'nothing' 1 '$<$100' 2 '$100 +' 9 'dk-nr'.

compute anyj$ = 2.
if donate eq 1 or range(jchar1,1,8) anyj$ = 1.
variable labels anyj$ 'give to any jewish charity and-or federation'.
value labels anyj$ 1 'give' 2 'not give'.

compute spamtfed = camtfed.
recode spamtfed (4=3).
variable labels spamtfed 'Amount Donated to Crosstab with Reasons for Giving'.
value labels spamtfed 0 'Nothing' 1 '<$100' 2 '$100-$500' 3 '$500+' 9 'DKNR'.

frequencies spamtfed amtfed donate to anyj$.

********************************************************************************************************************************************************************.
comment Page 15: Will. 
********************************************************************************************************************************************************************.
if (will eq 2) newwill = 100.
if (prov eq 2) newwill = 101.
if (prov eq 1 and jprov eq 1) newwill = 102.
if (prov eq 1 and jprov eq 2) newwill = 103.
if (prov eq 1 and jprov eq 3) newwill = 104.
variable labels newwill 'combined will variable'.
value labels newwill 100 'No Will' 101 'No Provision' 102 'Jewish Provision' 103 'Non-Jewish Provision' 104 'Jewish and Non-Jewish Provision'.


compute newwill2 = newwill.
recode newwill2 (104=102).
variable labels newwill2 'combined will variable 2'.
value labels newwill2 100 'No Will' 101 'No Provision' 102 'Jewish Provision' 103 'Non-Jewish Provision'.
frequencies newwill newwill2.

compute vol = 9.
if (volnj eq 1 and voljew eq 2) vol = 1.
if (volnj eq 2 and voljew eq 1) vol = 2.
if (volnj eq 1 and voljew eq 1) vol = 3.
if (volnj eq 2 and voljew eq 2) vol = 4.
variable labels vol 'Combined Volunteer Variable'.
value labels vol 1 'Non-Jewish, but not Jewish' 2 'Jewish, but not non-Jewish' 3 'Both' 4 'neither'.
missing values vol (9).
frequencies vol.


********************************************************************************************************************************************************************.
comment Page 17: agency changes.
********************************************************************************************************************************************************************.

compute notfam = 1.
if (famjcc eq 3 and famfed eq 3 and famjfs eq 3 and famjhome eq 3 and famhill eq 3 and famdays eq 3 and famalf eq 3) notfam = 2.
variable labels notfam 'familiar with none of the agencies'.
value labels notfam 1 'knows something' 2 'knows nothing'.
frequencies notfam.

compute cquafed = quafed.
recode cquafed (1=101)(2=102) (3,4 = 103).
value labels cquafed 101 'Excellent' 102 'Good' 103 'Fair or Poor'.
variable labels cquafed 'Quality of Federation'.
frequencies cquafed.
********************************************************************************************************************************************************************.
comment Page 17: Media.
********************************************************************************************************************************************************************.
weight wf.
if (famfed eq 3) fread eq 4.

compute jread2 = jread.
variable labels jread2 'Read Connecticut Jewish Ledger'.
recode jread2 (1,2 = 101)(3,4 = 102).
value labels jread2 101 'Always-Usually' 102 'Sometimes-Never'.

frequencies jread jread2.

compute fread2 = fread.
variable labels fread2 'Read FYI'.
recode fread2 (1,2 = 101) (3,4 = 102).
value labels fread2 101 'Always-Usually' 102 'Sometimes-Never'.

frequencies fread fread2.

********************************************************************************************************************************************************************.
comment Page 18: Income and Housing Value.
********************************************************************************************************************************************************************.
compute chval=hval.
recode chval (1 thru 2=1)(3 thru 4=2)(5 thru 7=3).
var labels  chval 'housing value in large cats'.
value labels chval 1 '< $100'  2 '$100-$250' 3 '$250+' 9 'dk-nr'.

comment careful because adding cases to income when we know is over $100,000.
compute cinc=inc.
recode cinc (1 thru 2=1)(3 thru 3=2)(4 thru 5=3)(6 thru 8=4).
if (inc100 eq 2) cinc eq 4.
var labels  cinc 'household income in large cats'.
value labels cinc 1 '< $25'  2 '$25-$50' 3 '$50-$100' 4 '$100+'.
frequencies cinc.

compute poverty = 2.
if any(id,4,96,163,178,381,479,600,603) poverty = 1.
variable labels poverty 'Live Below Poverty Line'.
value labels poverty 1 'Yes' 2 'no'.
frequencies poverty.


********************************************************************************************************************************************************************.
comment weighting factors.
********************************************************************************************************************************************************************.
frequencies tel.
recode tel(9=1).

compute wf = 1.
if (tel eq 2) wf = .5.
if (tel eq 3) wf = 0.333333333333.
if (tel ge 4) wf = 0.25.
frequencies wf.


**************************************************.
COMMENT WEIGHTING FACTORS ON VARIABLES.
**************************************************.
comment -- remember to run telephone weights first - remember to delete WF and rerun telephone weights
    and then new weights with each test of weighting factors.

*****************************************************************************************************.
Comment Weighting Factors -  RDD-DJN.
*****************************************************************************************************.
comment. first put on telephone weights.

COMMENT create temporary new variables for developing weighting factors.
compute thhsiz = hhsiz.
RECODE tHHSIZ (3 thru 20 = 3).
compute theadage = headage.
RECODE theadage (6=5).
compute tinter = inter.
recode tinter (2=1).
compute tgoisr = goisr.
recode tgoisr (3 thru 6 = 1) (9=2) (7=1).
value labels tgoisr 1 'Yes' 2 'No'.
frequencies tgoisr.
var labels tgoisr 'Go to Israel Variable for developing weighting factors'.
var labels thhsiz 'Household Size for developing weighting factors'
	theadage 'Age of Household head for developing weighting factors'
	tinter 'intermarriage variable for developing weighting factors'.
value labels theadage 2 'Under 35' 3 '35-49' 4 '50-64' 5 '65+'.
value labels tinter 1 'Inmarried' 3 'Intermarried'.
compute csynmem =  synmem.
recode csynmem (3=1).
var labels csynmem 'Synagogue membership'.
value labels csynmem 1 'Yes' 2 'No'.

compute cjccmem =  jccmem.
recode cjccmem (3=1).
var labels cjccmem 'JCC membership'.
value labels jccmem 1 'Yes' 2 'No'.
frequencies csynmem cjccmem thhsiz to tinter tgoisr.
 
Comment If INTER is a weight variable must undo 0 as a missing value to apply weights properly.
frequencies thhsiz to tinter.hone weights.

comment put telephone weights on on first running - remember to delete old weights rerun telephone weights and then
  new weights on each iteration of trying different variables.
recode cocr (6=5).
compute tjfed = jfed.
recode tjfed (3,4 = 1).
value labels tjfed 1 'Yes' 2  'No'.
variable labels tjfed 'Give to Federation'

weight wf.
CROSSTABS TABLES = area theadage cLOR tHHSIZ CFAMILY COCR cSYNMEM cJCCMEM tINTER FAMFED tjfed tGOISR CINC BY SOURCE
     /CELLS = COLUMN
    /STATISTICS = CHISQ.

comment to get "DJN Have" column for theadage.
CROSSTABS TABLES = theadage BY SOURCE
     /CELLS = COUNT.

comment if use headage as a variable, note that the values are 2,3,4,and 5!.
weight wf.
comment below is first attempt at WF with only headage.
IF (SOURCE EQ 2 AND theadage EQ 2) WF = 1.87833333333333 * WF.
IF (SOURCE EQ 2 AND theadage EQ 3) WF = 1.285174386  * WF.
IF (SOURCE EQ 2 AND theadage EQ 4) WF =  .87627737226 * WF.
IF (SOURCE EQ 2 AND theadage EQ 5) WF =  .82958139535 * WF.
frequencies wf.

CROSSTABS TABLES = area theadage cLOR tHHSIZ CFAMILY COCR cSYNMEM cJCCMEM tINTER FAMFED tjfeD tGOISR CINC BY SOURCE
     /CELLS = COLUMN
    /STATISTICS = CHISQ.

comment below is to figure out weighting factors for headage and cocr.
comment first make certain only weights on are telephone, then run the following for DJN have column.

frequencies wf.
temporary.
select if source eq 2.
crosstabs tables = theadage by cocr
	/cells = count.

comment run the following for the RDD % column.
temporary.
select if source eq 1.
crosstabs tables = theadage by cocr
	/cells = total.


*************************************************************************************************************************************.
comment below is second attempt at WF with HEADAGE and cocr -  get rid of weighting factors, then run
   telephone weighting factors for telephone and then the following statements.
frequencies wf.

IF (SOURCE EQ 2 and cocr eq 1 and tHEADAGE EQ 2) WF = 1* WF.
IF (SOURCE EQ 2 and cocr eq 1 and tHEADAGE EQ 3) WF =  5.368 * WF.
IF (SOURCE EQ 2 AND cocr eq 1 and tHEADAGE EQ 4) WF =  1.78933333 * WF.
IF (SOURCE EQ 2 AND cocr eq 1 and tHEADAGE eq 5) WF =  .46581818182 * WF.

IF (SOURCE EQ 2 and cocr eq 2 and tHEADAGE EQ 2) WF = 1.464 * WF.
IF (SOURCE EQ 2 and cocr eq 2 and tHEADAGE EQ 3) WF =  1.08948837209 * WF.
IF (SOURCE EQ 2 AND cocr eq 2 and tHEADAGE EQ 4) WF =  .61 * WF.
IF (SOURCE EQ 2 AND cocr eq 2 and tHEADAGE eq 5) WF =  .54324528302 * WF.

IF (SOURCE EQ 2 and cocr eq 3 and tHEADAGE EQ 2) WF = 1.647 * WF.
IF (SOURCE EQ 2 and cocr eq 3 and tHEADAGE EQ 3) WF =  1.60567741935 * WF.
IF (SOURCE EQ 2 AND cocr eq 3 and tHEADAGE EQ 4) WF =  .799777777778 * WF.
IF (SOURCE EQ 2 AND cocr eq 3 and tHEADAGE eq 5) WF =  1.15168 * WF.

IF (SOURCE EQ 2 and cocr eq 5 and tHEADAGE EQ 2) WF = 2.257 * WF.
IF (SOURCE EQ 2 and cocr eq 5 and tHEADAGE EQ 3) WF =  1.16863157895 * WF.
IF (SOURCE EQ 2 AND cocr eq 5 and tHEADAGE EQ 4) WF =  1.37410526316 * WF.
IF (SOURCE EQ 2 AND cocr eq 5 and tHEADAGE eq 5) WF =  1.41124324324 * WF.

frequencies wf.

CROSSTABS TABLES = area theadage cLOR tHHSIZ CFAMILY COCR cSYNMEM cJCCMEM tINTER FAMFED tjfeD tGOISR CINC BY SOURCE
     /CELLS = COLUMN
    /STATISTICS = CHISQ.
